defmodule Frenzy.Feed do
  use Ecto.Schema
  import Ecto.Changeset

  def to_fever(feed) do
    %{
      id: feed.id,
      favicon_id: feed.id,
      title: feed.title,
      url: feed.feed_url,
      site_url: feed.site_url,
      last_updated_on_time: Timex.to_unix(feed.last_updated),
      is_spark: false
    }
  end

  schema "feeds" do
    field :feed_url, :string
    field :last_updated, :utc_datetime
    field :site_url, :string
    field :title, :string

    has_many :items, Frenzy.Item, on_delete: :delete_all

    timestamps()
  end

  @doc false
  def changeset(feed, attrs) do
    feed
    |> cast(attrs, [:title, :feed_url, :site_url, :last_updated])
    |> validate_required([:feed_url])
  end
end
